@@ -283,6 +283,8 @@ list_item_to_sv ( hexchat_list *list, const char *const *fields )
 	return sv_2mortal (newRV_noinc ((SV *) hash));
 }
 
+#define WORD_ARRAY_LEN 32
+
 static AV *
 array2av (char *array[])
 {
@@ -293,7 +295,7 @@ array2av (char *array[])
 
 	for (
 		count = 1;
-		count < 32 && array[count] != NULL && array[count][0] != 0;
+		count < WORD_ARRAY_LEN && array[count] != NULL && array[count][0] != 0;
 		count++
 	) {
 		temp = newSVpv (array[count], 0);
@@ -1458,14 +1460,12 @@ perl_load_file (char *filename)
 									 "You must have a Visual C++ build of Perl "
 									 PERL_REQUIRED_VERSION " installed in order to\n"
 									 "run Perl scripts. A reboot may be required.\n\n"
-									 "http://hexchat.github.io/downloads.html\n\n"
 									 "I have found Perl 5.6, but that is too old.");
 				} else {
 					thread_mbox ("Cannot open " PERL_DLL "!\n\n"
 									 "You must have a Visual C++ build of Perl "
 									 PERL_REQUIRED_VERSION " installed in order to\n"
 									 "run Perl scripts. A reboot may be required.\n\n"
-									 "http://hexchat.github.io/downloads.html\n\n"
 									 "Make sure Perl's bin directory is in your PATH.");
 				}
 			}
