@@ -657,6 +657,9 @@ conn_fail:
 
 			server_cleanup (serv);
 
+			if (prefs.hex_net_auto_reconnectonfail)
+				auto_reconnect (serv, FALSE, -1);
+
 			return (0);
 		}
 
@@ -669,7 +672,11 @@ conn_fail:
 	} else
 	{
 		SSL_SESSION *session = SSL_get_session (serv->ssl);
+#if OPENSSL_VERSION_NUMBER >= 0x30400000L
+		if (session && SSL_SESSION_get_time_ex (session) + SSLTMOUT < time (NULL))
+#else
 		if (session && SSL_SESSION_get_time (session) + SSLTMOUT < time (NULL))
+#endif
 		{
 			g_snprintf (buf, sizeof (buf), "SSL handshake timed out");
 			EMIT_SIGNAL (XP_TE_CONNFAIL, serv->server_session, buf, NULL,
@@ -1765,7 +1772,9 @@ server_set_defaults (server *serv)
 	g_free (serv->chanmodes);
 	g_free (serv->nick_prefixes);
 	g_free (serv->nick_modes);
-
+#ifdef USE_OPENSSL
+        g_clear_pointer (&serv->scram_session, scram_session_free);
+#endif
 	serv->chantypes = g_strdup ("#&!+");
 	serv->chanmodes = g_strdup ("beI,k,l");
 	serv->nick_prefixes = g_strdup ("@%+");
@@ -1937,6 +1946,8 @@ server_free (server *serv)
 #ifdef USE_OPENSSL
 	if (serv->ctx)
 		_SSL_context_free (serv->ctx);
+
+        g_clear_pointer (&serv->scram_session, scram_session_free);
 #endif
 
 	fe_server_callback (serv);
