@@ -290,9 +290,11 @@ scrollback_load (session *sess)
 				text = strchr (buf + 3, ' ');
 				if (text && text[1])
 				{
+					text++; /* Use the text *after* the space */
+
 					if (prefs.hex_text_stripcolor_replay)
 					{
-						text = strip_color (text + 1, -1, STRIP_COLOR);
+						text = strip_color (text, -1, STRIP_COLOR);
 					}
 
 					fe_print_text (sess, text, stamp, TRUE);
@@ -771,7 +773,7 @@ text_convert_invalid (const gchar* text, gssize len, GIConv converter, const gch
 		 * But iconv may not convert everything till invalid_start_pos since the last few bytes may be part of a shift sequence.
 		 * So get the new bytes_read and use it as the actual invalid_start_pos to handle this.
 		 *
-		 * See https://github.com/hexchat/hexchat/issues/1758
+		 * See https://gitlab.com/bgermann/hexchat/-/issues/1758
 		 */
 		result_part = g_convert_with_iconv (current_start, invalid_start_pos, converter, &invalid_start_pos, &result_part_len, NULL);
 		g_iconv (converter, NULL, NULL, NULL, NULL);
@@ -814,6 +816,16 @@ text_convert_invalid (const gchar* text, gssize len, GIConv converter, const gch
 gchar *
 text_fixup_invalid_utf8 (const gchar* text, gssize len, gsize *len_out)
 {
+#if GLIB_CHECK_VERSION (2, 52, 0)
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+	gchar *result = g_utf8_make_valid (text, len);
+G_GNUC_END_IGNORE_DEPRECATIONS
+	if (len_out)
+	{
+		*len_out = strlen (result);
+	}
+	return result;
+#else
 	static GIConv utf8_fixup_converter = NULL;
 	if (utf8_fixup_converter == NULL)
 	{
@@ -821,6 +833,7 @@ text_fixup_invalid_utf8 (const gchar* text, gssize len, gsize *len_out)
 	}
 
 	return text_convert_invalid (text, len, utf8_fixup_converter, unicode_fallback_string, len_out);
+#endif
 }
 
 void
@@ -1284,6 +1297,13 @@ static char * const pevt_invited_help[] = {
 	N_("Server Name"),
 };
 
+static char * const pevt_invitedother_help[] = {
+	N_("Channel Name"),
+	N_("Nick of person who sent the invite"),
+	N_("Nick of person who was invited"),
+	N_("Server Name"),
+};
+
 static char * const pevt_usersonchan_help[] = {
 	N_("Channel Name"),
 	N_("Users"),
@@ -1494,6 +1514,17 @@ static char * const pevt_discon_help[] = {
 	N_("Error"),
 };
 
+static char * const pevt_stdrpl_help[] = {
+	N_("Error Code"),
+	N_("Error Message"),
+};
+
+static char * const pevt_stdrplcmd_help[] = {
+	N_("Command"),
+	N_("Error Code"),
+	N_("Error Message"),
+};
+
 #include "textevents.h"
 
 static void
@@ -2013,7 +2044,7 @@ text_emit (int index, session *sess, char *a, char *b, char *c, char *d,
 	unsigned int stripcolor_args = (chanopt_is_set (prefs.hex_text_stripcolor_msg, sess->text_strip) ? 0xFFFFFFFF : 0);
 	char tbuf[NICKLEN + 4];
 
-	if (prefs.hex_text_color_nicks && (index == XP_TE_CHANACTION || index == XP_TE_CHANMSG))
+	if (a != NULL && prefs.hex_text_color_nicks && (index == XP_TE_CHANACTION || index == XP_TE_CHANMSG))
 	{
 		g_snprintf (tbuf, sizeof (tbuf), "\003%d%s", text_color_of (a), a);
 		a = tbuf;
@@ -2098,7 +2129,8 @@ text_emit (int index, session *sess, char *a, char *b, char *c, char *d,
 		break;
 	}
 
-	sound_play_event (index);
+	if (!prefs.hex_away_omit_alerts || !sess->server->is_away)
+		sound_play_event (index);
 	display_event (sess, index, word, stripcolor_args, timestamp);
 }
 
