@@ -22,12 +22,6 @@
 
 #include "fe-gtk.h"
 
-#include <gtk/gtkeditable.h>
-#include <gtk/gtkframe.h>
-#include <gtk/gtkhbox.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkbutton.h>
-
 #include "../common/hexchat.h"
 #include "../common/hexchatc.h"
 #include "gtkutil.h"
@@ -143,7 +137,7 @@ ascii_open (void)
 		if (table_pos[0] == '\n' || i == 0)
 		{
 			table_pos++;
-			hbox = gtk_hbox_new (0, 0);
+			hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 			gtk_container_add (GTK_CONTAINER (vbox), hbox);
 			gtk_widget_show (hbox);
 			i++;
