@@ -459,7 +459,7 @@ chanlist_join (GtkWidget * wid, server *serv)
 			g_snprintf (tbuf, sizeof (tbuf), "join %s", chan);
 			handle_command (serv->server_session, tbuf, FALSE);
 		} else
-			gdk_beep ();
+			gdk_display_beep (gdk_display_get_default ());
 		g_free (chan);
 	}
 }
@@ -512,17 +512,18 @@ chanlist_save (GtkWidget * wid, server *serv)
 	GtkTreeModel *model = GET_MODEL (serv);
 
 	if (gtk_tree_model_get_iter_first (model, &iter))
-		gtkutil_file_req (_("Select an output filename"), chanlist_filereq_done,
+		gtkutil_file_req (NULL, _("Select an output filename"), chanlist_filereq_done,
 								serv, NULL, NULL, FRF_WRITE);
 }
 
 static gboolean
 chanlist_flash (server *serv)
 {
-	if (gtk_widget_get_state (serv->gui->chanlist_refresh) != GTK_STATE_ACTIVE)
-		gtk_widget_set_state (serv->gui->chanlist_refresh, GTK_STATE_ACTIVE);
+	GtkStateFlags state = gtk_widget_get_state_flags (serv->gui->chanlist_refresh);
+	if (!(state & GTK_STATE_FLAG_ACTIVE))
+		gtk_widget_set_state_flags (serv->gui->chanlist_refresh, GTK_STATE_FLAG_ACTIVE, FALSE);
 	else
-		gtk_widget_set_state (serv->gui->chanlist_refresh, GTK_STATE_PRELIGHT);
+		gtk_widget_unset_state_flags (serv->gui->chanlist_refresh, GTK_STATE_FLAG_ACTIVE);
 
 	return TRUE;
 }
@@ -621,18 +622,18 @@ chanlist_button_cb (GtkTreeView *tree, GdkEventButton *event, server *serv)
 	g_object_unref (menu);
 	g_signal_connect (G_OBJECT (menu), "selection-done",
 							G_CALLBACK (chanlist_menu_destroy), NULL);
-	mg_create_icon_item (_("_Join Channel"), GTK_STOCK_JUMP_TO, menu,
+	mg_create_icon_item (_("_Join Channel"), "go-jump", menu,
 								chanlist_join, serv);
-	mg_create_icon_item (_("_Copy Channel Name"), GTK_STOCK_COPY, menu,
+	mg_create_icon_item (_("_Copy Channel Name"), "edit-copy", menu,
 								chanlist_copychannel, serv);
-	mg_create_icon_item (_("Copy _Topic Text"), GTK_STOCK_COPY, menu,
+	mg_create_icon_item (_("Copy _Topic Text"), "edit-copy", menu,
 								chanlist_copytopic, serv);
 
 	chan = chanlist_get_selected (serv, FALSE);
 	menu_addfavoritemenu (serv, menu, chan, FALSE);
 	g_free (chan);
 
-	gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, NULL, 0, event->time);
+	gtk_menu_popup_at_pointer (GTK_MENU (menu), (GdkEvent *) event);
 
 	return TRUE;
 }
@@ -777,55 +778,48 @@ chanlist_opengui (server *serv, int do_refresh)
 	chanlist_add_column (view, COL_CHANNEL, 96, _("Channel"), FALSE);
 	chanlist_add_column (view, COL_USERS,   50, _("Users"),   TRUE);
 	chanlist_add_column (view, COL_TOPIC,   50, _("Topic"),   FALSE);
-	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (view), TRUE);
 	/* this is a speed up, but no horizontal scrollbar :( */
 	/*gtk_tree_view_set_fixed_height_mode (GTK_TREE_VIEW (view), TRUE);*/
 	gtk_widget_show (view);
 
 	/* ============================================================= */
 
-	table = gtk_table_new (4, 4, FALSE);
-	gtk_table_set_col_spacings (GTK_TABLE (table), 12);
-	gtk_table_set_row_spacings (GTK_TABLE (table), 3);
+	table = gtk_grid_new ();
+	gtk_grid_set_column_spacing (GTK_GRID (table), 12);
+	gtk_grid_set_row_spacing (GTK_GRID (table), 3);
 	gtk_box_pack_start (GTK_BOX (vbox), table, 0, 1, 0);
 	gtk_widget_show (table);
 
-	wid = gtkutil_button (NULL, GTK_STOCK_FIND, 0, chanlist_search_pressed, serv,
-								 _("_Search"));
+wid = gtkutil_button (NULL, "edit-find", 0, chanlist_search_pressed, serv,
+									 _("_Search"));
 	serv->gui->chanlist_search = wid;
-	gtk_table_attach (GTK_TABLE (table), wid, 3, 4, 3, 4,
-							GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 0);
+	gtk_grid_attach (GTK_GRID (table), wid, 3, 3, 1, 1);
 
-	wid = gtkutil_button (NULL, GTK_STOCK_REFRESH, 0, chanlist_refresh, serv,
-								 _("_Download List"));
+	wid = gtkutil_button (NULL, "view-refresh", 0, chanlist_refresh, serv,
+									 _("_Download List"));
 	serv->gui->chanlist_refresh = wid;
-	gtk_table_attach (GTK_TABLE (table), wid, 3, 4, 2, 3,
-							GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 0);
+	gtk_grid_attach (GTK_GRID (table), wid, 3, 2, 1, 1);
 
-	wid = gtkutil_button (NULL, GTK_STOCK_SAVE_AS, 0, chanlist_save, serv,
-								 _("Save _List..."));
+	wid = gtkutil_button (NULL, "document-save-as", 0, chanlist_save, serv,
+									 _("Save _List..."));
 	serv->gui->chanlist_savelist = wid;
-	gtk_table_attach (GTK_TABLE (table), wid, 3, 4, 1, 2,
-							GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 0);
+	gtk_grid_attach (GTK_GRID (table), wid, 3, 1, 1, 1);
 
-	wid = gtkutil_button (NULL, GTK_STOCK_JUMP_TO, 0, chanlist_join, serv,
+	wid = gtkutil_button (NULL, "go-jump", 0, chanlist_join, serv,
 						 _("_Join Channel"));
 	serv->gui->chanlist_join = wid;
-	gtk_table_attach (GTK_TABLE (table), wid, 3, 4, 0, 1,
-							GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 0);
+	gtk_grid_attach (GTK_GRID (table), wid, 3, 0, 1, 1);
 
 	/* ============================================================= */
 
 	wid = gtk_label_new (_("Show only:"));
-	gtk_misc_set_alignment (GTK_MISC (wid), 0, 0.5);
-	gtk_table_attach (GTK_TABLE (table), wid, 0, 1, 3, 4,
-							GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 0);
+	gtk_widget_set_halign (wid, GTK_ALIGN_START);
+	gtk_grid_attach (GTK_GRID (table), wid, 0, 3, 1, 1);
 	gtk_widget_show (wid);
 
-	hbox = gtk_hbox_new (0, 0);
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_box_set_spacing (GTK_BOX (hbox), 9);
-	gtk_table_attach (GTK_TABLE (table), hbox, 1, 2, 3, 4,
-							GTK_FILL, GTK_FILL, 0, 0);
+	gtk_grid_attach (GTK_GRID (table), hbox, 1, 3, 1, 1);
 	gtk_widget_show (hbox);
 
 	wid = gtk_label_new (_("channels with"));
@@ -860,15 +854,13 @@ chanlist_opengui (server *serv, int do_refresh)
 	/* ============================================================= */
 
 	wid = gtk_label_new (_("Look in:"));
-	gtk_misc_set_alignment (GTK_MISC (wid), 0, 0.5);
-	gtk_table_attach (GTK_TABLE (table), wid, 0, 1, 2, 3,
-							GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 0);
+	gtk_widget_set_halign (wid, GTK_ALIGN_START);
+	gtk_grid_attach (GTK_GRID (table), wid, 0, 2, 1, 1);
 	gtk_widget_show (wid);
 
-	hbox = gtk_hbox_new (0, 0);
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_box_set_spacing (GTK_BOX (hbox), 12);
-	gtk_table_attach (GTK_TABLE (table), hbox, 1, 2, 2, 3,
-							GTK_FILL, GTK_FILL, 0, 0);
+	gtk_grid_attach (GTK_GRID (table), hbox, 1, 2, 1, 1);
 	gtk_widget_show (hbox);
 
 	wid = gtk_check_button_new_with_label (_("Channel name"));
@@ -892,9 +884,8 @@ chanlist_opengui (server *serv, int do_refresh)
 	/* ============================================================= */
 
 	wid = gtk_label_new (_("Search type:"));
-	gtk_misc_set_alignment (GTK_MISC (wid), 0, 0.5);
-	gtk_table_attach (GTK_TABLE (table), wid, 0, 1, 1, 2,
-							GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 0);
+	gtk_widget_set_halign (wid, GTK_ALIGN_START);
+	gtk_grid_attach (GTK_GRID (table), wid, 0, 1, 1, 1);
 	gtk_widget_show (wid);
 
 	wid = gtk_combo_box_text_new ();
@@ -902,8 +893,7 @@ chanlist_opengui (server *serv, int do_refresh)
 	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (wid), _("Pattern Match (Wildcards)"));
 	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (wid), _("Regular Expression"));
 	gtk_combo_box_set_active (GTK_COMBO_BOX (wid), serv->gui->chanlist_search_type);
-	gtk_table_attach (GTK_TABLE (table), wid, 1, 2, 1, 2,
-							GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 0);
+	gtk_grid_attach (GTK_GRID (table), wid, 1, 1, 1, 1);
 	g_signal_connect (G_OBJECT (wid), "changed",
 							G_CALLBACK (chanlist_combo_cb), serv);
 	gtk_widget_show (wid);
@@ -911,9 +901,8 @@ chanlist_opengui (server *serv, int do_refresh)
 	/* ============================================================= */
 
 	wid = gtk_label_new (_("Find:"));
-	gtk_misc_set_alignment (GTK_MISC (wid), 0, 0.5);
-	gtk_table_attach (GTK_TABLE (table), wid, 0, 1, 0, 1,
-							GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 0);
+	gtk_widget_set_halign (wid, GTK_ALIGN_START);
+	gtk_grid_attach (GTK_GRID (table), wid, 0, 0, 1, 1);
 	gtk_widget_show (wid);
 
 	wid = gtk_entry_new ();
@@ -923,8 +912,8 @@ chanlist_opengui (server *serv, int do_refresh)
 	g_signal_connect (G_OBJECT (wid), "activate",
 							  G_CALLBACK (chanlist_search_pressed),
 							  (gpointer) serv);
-	gtk_table_attach (GTK_TABLE (table), wid, 1, 2, 0, 1,
-							GTK_EXPAND | GTK_FILL, 0, 0, 0);
+	gtk_widget_set_hexpand (wid, TRUE);
+	gtk_grid_attach (GTK_GRID (table), wid, 1, 0, 1, 1);
 	gtk_widget_show (wid);
 	serv->gui->chanlist_wild = wid;
 
@@ -932,9 +921,8 @@ chanlist_opengui (server *serv, int do_refresh)
 
 	/* ============================================================= */
 
-	wid = gtk_vseparator_new ();
-	gtk_table_attach (GTK_TABLE (table), wid, 2, 3, 0, 5,
-							GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 0);
+	wid = gtk_separator_new (GTK_ORIENTATION_VERTICAL);
+	gtk_grid_attach (GTK_GRID (table), wid, 2, 0, 1, 5);
 	gtk_widget_show (wid);
 
 	g_signal_connect (G_OBJECT (serv->gui->chanlist_window), "destroy",
