@@ -111,13 +111,12 @@ cv_tree_init (chanview *cv)
 													 GTK_SHADOW_IN);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (win),
 											  GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
-	gtk_container_add (GTK_CONTAINER (cv->box), win);
+	gtk_box_pack_start (GTK_BOX (cv->box), win, TRUE, TRUE, 0);
 	gtk_widget_show (win);
 
 	view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (cv->store));
 	gtk_widget_set_name (view, "hexchat-tree");
-	if (cv->style)
-		gtk_widget_set_style (view, cv->style);
+	/* Font is applied via cell renderers in the tree column setup */
 	/*gtk_widget_modify_base (view, GTK_STATE_NORMAL, &colors[COL_BG]);*/
 	gtk_widget_set_can_focus (view, FALSE);
 	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (view), FALSE);
