@@ -58,7 +58,7 @@
 #include <canberra.h>
 #endif
 
-GdkPixmap *channelwin_pix;
+/* GdkPixmap removed - not used in GTK-3 */
 
 #ifdef USE_LIBCANBERRA
 static ca_context *ca_con;
@@ -247,70 +247,60 @@ fe_args (int argc, char *argv[])
 	return -1;
 }
 
-const char cursor_color_rc[] =
-	"style \"xc-ib-st\""
-	"{"
-		"GtkEntry::cursor-color=\"#%02x%02x%02x\""
-	"}"
-	"widget \"*.hexchat-inputbox\" style : application \"xc-ib-st\"";
+/* GTK-3 CSS for input styling */
+static GtkCssProvider *input_css_provider = NULL;
+PangoFontDescription *input_font = NULL;
 
-static const char adwaita_workaround_rc[] =
-	"style \"hexchat-input-workaround\""
-	"{"
-		"engine \"pixmap\" {"
-			"image {"
-				"function = FLAT_BOX\n"
-				"state    = NORMAL\n"
-			"}"
-			"image {"
-				"function = FLAT_BOX\n"
-				"state    = ACTIVE\n"
-			"}"
-		"}"
-	"}"
-	"widget \"*.hexchat-inputbox\" style \"hexchat-input-workaround\"";
-
-GtkStyle *
-create_input_style (GtkStyle *style)
+PangoFontDescription *
+create_input_style (void)
 {
-	char buf[256];
-	static int done_rc = FALSE;
+	char buf[512];
+	PangoFontDescription *font;
+	GdkRGBA fg_color, bg_color;
 
-	pango_font_description_free (style->font_desc);
-	style->font_desc = pango_font_description_from_string (prefs.hex_text_font);
+	font = pango_font_description_from_string (prefs.hex_text_font);
 
 	/* fall back */
-	if (pango_font_description_get_size (style->font_desc) == 0)
+	if (pango_font_description_get_size (font) == 0)
 	{
 		g_snprintf (buf, sizeof (buf), _("Failed to open font:\n\n%s"), prefs.hex_text_font);
 		fe_message (buf, FE_MSG_ERROR);
-		pango_font_description_free (style->font_desc);
-		style->font_desc = pango_font_description_from_string ("sans 11");
+		pango_font_description_free (font);
+		font = pango_font_description_from_string ("sans 11");
 	}
 
-	if (prefs.hex_gui_input_style && !done_rc)
+	if (prefs.hex_gui_input_style)
 	{
-		GtkSettings *settings = gtk_settings_get_default ();
-		char *theme_name;
+		fg_color = colors[COL_FG];
+		bg_color = colors[COL_BG];
 
-		/* gnome-themes-standard 3.20+ relies on images to do theming
-		 * so we have to override that. */
-		g_object_get (settings, "gtk-theme-name", &theme_name, NULL);
-		if (g_str_has_prefix (theme_name, "Adwaita") || g_str_has_prefix (theme_name, "Yaru"))
-			gtk_rc_parse_string (adwaita_workaround_rc);
-		g_free (theme_name);
+		/* Create CSS for input box styling */
+		g_snprintf (buf, sizeof (buf),
+			".hexchat-inputbox { "
+			"color: rgba(%d, %d, %d, %d); "
+			"background-color: rgba(%d, %d, %d, %d); "
+			"caret-color: rgba(%d, %d, %d, %d); "
+			"}",
+			(int)(fg_color.red * 255), (int)(fg_color.green * 255), 
+			(int)(fg_color.blue * 255), (int)(fg_color.alpha * 255),
+			(int)(bg_color.red * 255), (int)(bg_color.green * 255), 
+			(int)(bg_color.blue * 255), (int)(bg_color.alpha * 255),
+			(int)(fg_color.red * 255), (int)(fg_color.green * 255), 
+			(int)(fg_color.blue * 255), (int)(fg_color.alpha * 255));
 
-		done_rc = TRUE;
-		sprintf (buf, cursor_color_rc, (colors[COL_FG].red >> 8),
-			(colors[COL_FG].green >> 8), (colors[COL_FG].blue >> 8));
-		gtk_rc_parse_string (buf);
+		if (!input_css_provider)
+		{
+			input_css_provider = gtk_css_provider_new ();
+			gtk_style_context_add_provider_for_screen (
+				gdk_screen_get_default (),
+				GTK_STYLE_PROVIDER (input_css_provider),
+				GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+		}
+
+		gtk_css_provider_load_from_data (input_css_provider, buf, -1, NULL);
 	}
 
-	style->bg[GTK_STATE_NORMAL] = colors[COL_FG];
-	style->base[GTK_STATE_NORMAL] = colors[COL_BG];
-	style->text[GTK_STATE_NORMAL] = colors[COL_FG];
-
-	return style;
+	return font;
 }
 
 void
@@ -323,8 +313,8 @@ fe_init (void)
 #ifdef HAVE_GTK_MAC
 	gtkosx_application_set_dock_icon_pixbuf (osx_app, pix_hexchat);
 #endif
-	channelwin_pix = pixmap_load_from_file (prefs.hex_text_background);
-	input_style = create_input_style (gtk_style_new ());
+	/* GdkPixmap background removed for GTK-3 */
+	input_font = create_input_style ();
 }
 
 #ifdef HAVE_GTK_MAC
@@ -664,13 +654,13 @@ fe_print_text (struct session *sess, char *text, time_t stamp,
 		return;
 
 	if (sess == current_tab)
-		fe_set_tab_color (sess, 0);
+		fe_set_tab_color (sess, FE_COLOR_NONE);
 	else if (sess->tab_state & TAB_STATE_NEW_HILIGHT)
-		fe_set_tab_color (sess, 3);
+		fe_set_tab_color (sess, FE_COLOR_NEW_HILIGHT);
 	else if (sess->tab_state & TAB_STATE_NEW_MSG)
-		fe_set_tab_color (sess, 2);
+		fe_set_tab_color (sess, FE_COLOR_NEW_MSG);
 	else
-		fe_set_tab_color (sess, 1);
+		fe_set_tab_color (sess, FE_COLOR_NEW_DATA);
 }
 
 void
@@ -698,7 +688,7 @@ fe_beep (session *sess)
 
 	if (ca_context_play (ca_con, 0, CA_PROP_EVENT_ID, "message-new-instant", NULL) != 0)
 #endif
-	gdk_beep ();
+	gdk_display_beep (gdk_display_get_default ());
 #endif
 }
 
@@ -903,7 +893,7 @@ fe_confirm (const char *message, void (*yesproc)(void *), void (*noproc)(void *)
 	if (dcc->file)
 	{
 		char *filepath = g_build_filename (prefs.hex_dcc_dir, dcc->file, NULL);
-		gtkutil_file_req (message, dcc_saveas_cb, ud, filepath, NULL,
+		gtkutil_file_req (NULL, message, dcc_saveas_cb, ud, filepath, NULL,
 								FRF_WRITE|FRF_NOASKOVERWRITE|FRF_FILTERISINITIAL);
 		g_free (filepath);
 	}
@@ -1054,6 +1044,45 @@ osx_show_uri (const char *url)
 
 #endif
 
+static inline char *
+escape_uri (const char *uri)
+{
+	return g_uri_escape_string(uri, G_URI_RESERVED_CHARS_GENERIC_DELIMITERS G_URI_RESERVED_CHARS_SUBCOMPONENT_DELIMITERS, FALSE);
+}
+
+static inline gboolean
+uri_contains_forbidden_characters (const char *uri)
+{
+	while (*uri)
+	{
+		if (!g_ascii_isalnum (*uri) && !strchr ("-._~:/?#[]@!$&'()*+,;=", *uri))
+			return TRUE;
+		uri++;
+	}
+
+	return FALSE;
+}
+
+static char *
+maybe_escape_uri (const char *uri)
+{
+	/* The only way to know if a string has already been escaped or not
+	 * is by fulling parsing each segement but we can try some more simple heuristics. */
+
+	/* If we find characters that should clearly be escaped. */
+	if (uri_contains_forbidden_characters (uri))
+		return escape_uri (uri);
+
+	/* If it fails to be unescaped then it was not escaped. */
+	char *unescaped = g_uri_unescape_string (uri, NULL);
+	if (!unescaped)
+		return escape_uri (uri);
+	g_free (unescaped);
+
+	/* At this point it is probably safe to pass through as-is. */
+	return g_strdup (uri);
+}
+
 static void
 fe_open_url_inner (const char *url)
 {
@@ -1071,9 +1100,9 @@ fe_open_url_inner (const char *url)
 #elif defined(__APPLE__)
     osx_show_uri (url);
 #else
-	char *escaped_url = g_uri_escape_string (url, G_URI_RESERVED_CHARS_GENERIC_DELIMITERS G_URI_RESERVED_CHARS_SUBCOMPONENT_DELIMITERS,
-	                                         FALSE);
-	gtk_show_uri (NULL, escaped_url, GDK_CURRENT_TIME, NULL);
+	char *escaped_url = maybe_escape_uri (url);
+	g_debug ("Opening URL \"%s\" (%s)", escaped_url, url);
+	gtk_show_uri_on_window (NULL, escaped_url, GDK_CURRENT_TIME, NULL);
 	g_free (escaped_url);
 #endif
 }
@@ -1176,7 +1205,7 @@ fe_get_file (const char *title, char *initial,
 {
 	/* OK: Call callback once per file, then once more with file=NULL. */
 	/* CANCEL: Call callback once with file=NULL. */
-	gtkutil_file_req (title, callback, userdata, initial, NULL, flags | FRF_FILTERISINITIAL);
+	gtkutil_file_req (NULL, title, callback, userdata, initial, NULL, flags | FRF_FILTERISINITIAL);
 }
 
 void
