@@ -31,6 +31,14 @@
 #include <pango/pangocairo.h>
 #endif
 
+#ifdef GDK_WINDOWING_X11
+#include <gdk/gdkx.h>
+#endif
+
+#ifdef GDK_WINDOWING_WAYLAND
+#include <gdk/gdkwayland.h>
+#endif
+
 #include "../common/hexchat.h"
 #include "../common/fe.h"
 #include "../common/util.h"
@@ -186,7 +194,7 @@ gtkutil_file_req_response (GtkWidget *dialog, gint res, struct file_req *freq)
 }
 
 void
-gtkutil_file_req (const char *title, void *callback, void *userdata, char *filter, char *extensions,
+gtkutil_file_req (GtkWindow *parent, const char *title, void *callback, void *userdata, char *filter, char *extensions,
 						int flags)
 {
 	struct file_req *freq;
@@ -200,8 +208,8 @@ gtkutil_file_req (const char *title, void *callback, void *userdata, char *filte
 	{
 		dialog = gtk_file_chooser_dialog_new (title, NULL,
 												GTK_FILE_CHOOSER_ACTION_SAVE,
-												GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-												GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT,
+												_("_Cancel"), GTK_RESPONSE_CANCEL,
+												_("_Save"), GTK_RESPONSE_ACCEPT,
 												NULL);
 
 		if (!(flags & FRF_NOASKOVERWRITE))
@@ -210,8 +218,8 @@ gtkutil_file_req (const char *title, void *callback, void *userdata, char *filte
 	else
 		dialog = gtk_file_chooser_dialog_new (title, NULL,
 												GTK_FILE_CHOOSER_ACTION_OPEN,
-												GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-												GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
+												_("_Cancel"), GTK_RESPONSE_CANCEL,
+												_("_Open"), GTK_RESPONSE_ACCEPT,
 												NULL);
 
 	if (filter && filter[0] && (flags & FRF_FILTERISINITIAL))
@@ -265,6 +273,16 @@ gtkutil_file_req (const char *title, void *callback, void *userdata, char *filte
 							G_CALLBACK (gtkutil_file_req_response), freq);
 	g_signal_connect (G_OBJECT (dialog), "destroy",
 						   G_CALLBACK (gtkutil_file_req_destroy), (gpointer) freq);
+
+	if (parent)
+		gtk_window_set_transient_for (GTK_WINDOW (dialog), parent);
+
+	if (flags & FRF_MODAL)
+	{
+		g_assert (parent);
+		gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
+	}
+
 	gtk_widget_show (dialog);
 }
 
@@ -342,8 +360,8 @@ fe_get_str (char *msg, char *def, void *callback, void *userdata)
 	extern GtkWidget *parent_window;
 
 	dialog = gtk_dialog_new_with_buttons (msg, NULL, 0,
-										GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT,
-										GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
+												_("_Cancel"), GTK_RESPONSE_REJECT,
+												_("_OK"), GTK_RESPONSE_ACCEPT,
 										NULL);
 
 	gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (parent_window));
@@ -358,7 +376,7 @@ fe_get_str (char *msg, char *def, void *callback, void *userdata)
 		gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_MOUSE);
 	}
 
-	hbox = gtk_hbox_new (TRUE, 0);
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 
 	g_object_set_data (G_OBJECT (dialog), "cb", callback);
 	g_object_set_data (G_OBJECT (dialog), "ud", userdata);
@@ -437,14 +455,14 @@ fe_get_int (char *msg, int def, void *callback, void *userdata)
 	extern GtkWidget *parent_window;
 
 	dialog = gtk_dialog_new_with_buttons (msg, NULL, 0,
-										GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT,
-										GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
-										NULL);
+												_("_Cancel"), GTK_RESPONSE_REJECT,
+												_("_OK"), GTK_RESPONSE_ACCEPT,
+												NULL);
 	gtk_box_set_homogeneous (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), TRUE);
 	gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_MOUSE);
 	gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (parent_window));
 
-	hbox = gtk_hbox_new (TRUE, 0);
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 
 	g_object_set_data (G_OBJECT (dialog), "cb", callback);
 	g_object_set_data (G_OBJECT (dialog), "ud", userdata);
@@ -454,7 +472,7 @@ fe_get_int (char *msg, int def, void *callback, void *userdata)
 	gtk_adjustment_set_lower (adj, 0);
 	gtk_adjustment_set_upper (adj, 1024);
 	gtk_adjustment_set_step_increment (adj, 1);
-	gtk_adjustment_changed (adj);
+	g_object_notify (G_OBJECT (adj), "upper"); /* GTK-3: use notify instead of deprecated gtk_adjustment_changed */
 	gtk_spin_button_set_value ((GtkSpinButton*)spin, def);
 	gtk_box_pack_end (GTK_BOX (hbox), spin, 0, 0, 0);
 
@@ -477,8 +495,8 @@ fe_get_bool (char *title, char *prompt, void *callback, void *userdata)
 	extern GtkWidget *parent_window;
 
 	dialog = gtk_dialog_new_with_buttons (title, NULL, 0,
-		GTK_STOCK_NO, GTK_RESPONSE_REJECT,
-		GTK_STOCK_YES, GTK_RESPONSE_ACCEPT,
+		_("_No"), GTK_RESPONSE_REJECT,
+		_("_Yes"), GTK_RESPONSE_ACCEPT,
 		NULL);
 	gtk_box_set_homogeneous (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), TRUE);
 	gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_MOUSE);
@@ -499,7 +517,7 @@ fe_get_bool (char *title, char *prompt, void *callback, void *userdata)
 }
 
 GtkWidget *
-gtkutil_button (GtkWidget *box, char *stock, char *tip, void *callback,
+gtkutil_button (GtkWidget *box, char *icon_name, char *tip, void *callback,
 					 void *userdata, char *labeltext)
 {
 	GtkWidget *wid, *img, *bbox;
@@ -509,20 +527,24 @@ gtkutil_button (GtkWidget *box, char *stock, char *tip, void *callback,
 	if (labeltext)
 	{
 		gtk_button_set_label (GTK_BUTTON (wid), labeltext);
-		gtk_button_set_image (GTK_BUTTON (wid), gtk_image_new_from_stock (stock, GTK_ICON_SIZE_MENU));
+		if (icon_name)
+			gtk_button_set_image (GTK_BUTTON (wid), gtk_image_new_from_icon_name (icon_name, GTK_ICON_SIZE_MENU));
 		gtk_button_set_use_underline (GTK_BUTTON (wid), TRUE);
 		if (box)
 			gtk_container_add (GTK_CONTAINER (box), wid);
 	}
 	else
 	{
-		bbox = gtk_hbox_new (0, 0);
+		bbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 		gtk_container_add (GTK_CONTAINER (wid), bbox);
 		gtk_widget_show (bbox);
 
-		img = gtk_image_new_from_stock (stock, GTK_ICON_SIZE_MENU);
-		gtk_container_add (GTK_CONTAINER (bbox), img);
-		gtk_widget_show (img);
+		if (icon_name)
+		{
+			img = gtk_image_new_from_icon_name (icon_name, GTK_ICON_SIZE_MENU);
+			gtk_container_add (GTK_CONTAINER (bbox), img);
+			gtk_widget_show (img);
+		}
 		gtk_box_pack_start (GTK_BOX (box), wid, 0, 0, 0);
 	}
 
@@ -645,7 +667,7 @@ gtkutil_treeview_new (GtkWidget *box, GtkTreeModel *model,
 	char *title, *attr;
 
 	win = gtk_scrolled_window_new (0, 0);
-	gtk_container_add (GTK_CONTAINER (box), win);
+	gtk_box_pack_start (GTK_BOX (box), win, TRUE, TRUE, 0);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (win),
 											  GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 	gtk_widget_show (win);
@@ -735,6 +757,54 @@ gtkutil_treeview_get_selected (GtkTreeView *view, GtkTreeIter *iter_ret, ...)
 	return has_selected;
 }
 
+gboolean
+gtkutil_tray_icon_supported (GtkWindow *window)
+{
+	GdkScreen *screen;
+	GdkDisplay *display;
+
+	/* Check if window is valid */
+	if (!window || !GTK_IS_WIDGET (window))
+		return TRUE;
+
+	screen = gtk_window_get_screen (window);
+	display = gdk_screen_get_display (screen);
+
+#ifdef GDK_WINDOWING_WAYLAND
+	/* GtkStatusIcon doesn't work on Wayland, need AppIndicator */
+	if (GDK_IS_WAYLAND_DISPLAY (display))
+#ifdef USE_APPINDICATOR
+		return TRUE;
+#else
+		return FALSE;
+#endif
+#endif
+
+#ifndef GDK_WINDOWING_X11
+	return TRUE;
+#else
+	/* Check if we're actually running on X11 */
+	if (!GDK_IS_X11_DISPLAY (display))
+		return TRUE;
+
+	int screen_number = gdk_x11_screen_get_screen_number (screen);
+	Display *xdisplay = gdk_x11_display_get_xdisplay (display);
+	char *selection_name = g_strdup_printf ("_NET_SYSTEM_TRAY_S%d", screen_number);
+	Atom selection_atom = XInternAtom (xdisplay, selection_name, False);
+	Window tray_window = None;
+
+	XGrabServer (xdisplay);
+
+	tray_window = XGetSelectionOwner (xdisplay, selection_atom);
+
+	XUngrabServer (xdisplay);
+	XFlush (xdisplay);
+	g_free (selection_name);
+
+	return (tray_window != None);
+#endif
+}
+
 #if defined (WIN32) || defined (__APPLE__)
 gboolean
 gtkutil_find_font (const char *fontname)
