@@ -27,6 +27,7 @@ extern GdkPixbuf *pix_ulist_owner;
 extern GdkPixbuf *pix_ulist_founder;
 extern GdkPixbuf *pix_ulist_netop;
 
+extern GdkPixbuf *pix_tray_normal;
 extern GdkPixbuf *pix_tray_fileoffer;
 extern GdkPixbuf *pix_tray_highlight;
 extern GdkPixbuf *pix_tray_message;
@@ -39,7 +40,6 @@ extern GdkPixbuf *pix_tree_util;
 extern GdkPixbuf *pix_book;
 extern GdkPixbuf *pix_hexchat;
 
-extern GdkPixmap *pixmap_load_from_file (char *file);
 extern void pixmaps_init (void);
 
 #endif
