@@ -31,6 +31,10 @@
 #include "menu.h"
 #include "gtkutil.h"
 
+#ifdef USE_APPINDICATOR
+#include <libayatana-appindicator-glib/ayatana-appindicator.h>
+#endif
+
 #ifndef WIN32
 #include <unistd.h>
 #endif
@@ -61,7 +65,17 @@ typedef GdkPixbuf* TrayIcon;
 #define ICON_FILE pix_tray_fileoffer
 #define TIMEOUT 500
 
+#ifdef USE_APPINDICATOR
+static AppIndicator *appindicator;
+static GMenu *app_menu;
+static GSimpleActionGroup *action_group;
+#define ICON_NORMAL_NAME "hexchat"
+#define ICON_MSG_NAME "hexchat-message"
+#define ICON_HILIGHT_NAME "hexchat-highlight"
+#define ICON_FILE_NAME "hexchat-fileoffer"
+#else
 static GtkStatusIcon *sticon;
+#endif
 static gint flash_tag;
 static TrayStatus tray_status;
 #ifdef WIN32
@@ -139,8 +153,13 @@ tray_count_networks (void)
 void
 fe_tray_set_tooltip (const char *text)
 {
+#ifdef USE_APPINDICATOR
+	/* AppIndicator doesn't support tooltips directly */
+	(void)text;
+#else
 	if (sticon)
 		gtk_status_icon_set_tooltip_text (sticon, text);
+#endif
 }
 
 static void
@@ -168,6 +187,12 @@ tray_stop_flash (void)
 		flash_tag = 0;
 	}
 
+#ifdef USE_APPINDICATOR
+	if (appindicator)
+	{
+		app_indicator_set_icon (appindicator, ICON_NORMAL_NAME, NULL);
+	}
+#else
 	if (sticon)
 	{
 		gtk_status_icon_set_from_pixbuf (sticon, ICON_NORMAL);
@@ -179,6 +204,7 @@ tray_stop_flash (void)
 		else
 			tray_set_tipf ("%s - %s", _("Not connected."), _(DISPLAY_NAME));
 	}
+#endif
 
 	if (custom_icon1)
 	{
@@ -204,6 +230,43 @@ tray_reset_counts (void)
 	tray_file_count = 0;
 }
 
+#ifdef USE_APPINDICATOR
+static gboolean flash_state = FALSE;
+static const char *flash_icon_name = NULL;
+
+static int
+tray_timeout_cb (gpointer userdata)
+{
+	if (!appindicator)
+		return 0;
+
+	flash_state = !flash_state;
+	if (flash_state && flash_icon_name)
+		app_indicator_set_icon (appindicator, flash_icon_name, NULL);
+	else
+		app_indicator_set_icon (appindicator, ICON_NORMAL_NAME, NULL);
+
+	return 1;
+}
+
+static void
+tray_set_flash (const char *icon_name)
+{
+	if (!appindicator)
+		return;
+
+	/* no flashing if window is focused */
+	if (tray_get_window_status () == WS_FOCUSED)
+		return;
+
+	tray_stop_flash ();
+
+	flash_icon_name = icon_name;
+	app_indicator_set_icon (appindicator, icon_name, NULL);
+	if (prefs.hex_gui_tray_blink)
+		flash_tag = g_timeout_add (TIMEOUT, tray_timeout_cb, NULL);
+}
+#else
 static int
 tray_timeout_cb (TrayIcon icon)
 {
@@ -251,11 +314,17 @@ tray_set_flash (TrayIcon icon)
 	if (prefs.hex_gui_tray_blink)
 		flash_tag = g_timeout_add (TIMEOUT, (GSourceFunc) tray_timeout_cb, icon);
 }
+#endif
 
 void
 fe_tray_set_flash (const char *filename1, const char *filename2, int tout)
 {
 	tray_apply_setup ();
+#ifdef USE_APPINDICATOR
+	if (!appindicator)
+		return;
+	/* Custom icon flash not supported with AppIndicator */
+#else
 	if (!sticon)
 		return;
 
@@ -271,12 +340,34 @@ fe_tray_set_flash (const char *filename1, const char *filename2, int tout)
 	gtk_status_icon_set_from_pixbuf (sticon, custom_icon1);
 	flash_tag = g_timeout_add (tout, (GSourceFunc) tray_timeout_cb, NULL);
 	tray_status = TS_CUSTOM;
+#endif
 }
 
 void
 fe_tray_set_icon (feicon icon)
 {
 	tray_apply_setup ();
+#ifdef USE_APPINDICATOR
+	if (!appindicator)
+		return;
+
+	tray_stop_flash ();
+
+	switch (icon)
+	{
+	case FE_ICON_NORMAL:
+		break;
+	case FE_ICON_MESSAGE:
+	case FE_ICON_PRIVMSG:
+		tray_set_flash (ICON_MSG_NAME);
+		break;
+	case FE_ICON_HIGHLIGHT:
+		tray_set_flash (ICON_HILIGHT_NAME);
+		break;
+	case FE_ICON_FILEOFFER:
+		tray_set_flash (ICON_FILE_NAME);
+	}
+#else
 	if (!sticon)
 		return;
 
@@ -296,12 +387,17 @@ fe_tray_set_icon (feicon icon)
 	case FE_ICON_FILEOFFER:
 		tray_set_flash (ICON_FILE);
 	}
+#endif
 }
 
 void
 fe_tray_set_file (const char *filename)
 {
 	tray_apply_setup ();
+#ifdef USE_APPINDICATOR
+	/* Custom icon from file not supported with AppIndicator */
+	(void)filename;
+#else
 	if (!sticon)
 		return;
 
@@ -313,6 +409,7 @@ fe_tray_set_file (const char *filename)
 		gtk_status_icon_set_from_pixbuf (sticon, custom_icon1);
 		tray_status = TS_CUSTOM;
 	}
+#endif
 }
 
 gboolean
@@ -324,8 +421,13 @@ tray_toggle_visibility (gboolean force_hide)
 	static int fullscreen;
 	GtkWindow *win;
 
+#ifdef USE_APPINDICATOR
+	if (!appindicator)
+		return FALSE;
+#else
 	if (!sticon)
 		return FALSE;
+#endif
 
 	/* ph may have an invalid context now */
 	hexchat_set_context (ph, hexchat_find_context (ph, NULL, NULL));
@@ -359,6 +461,7 @@ tray_toggle_visibility (gboolean force_hide)
 		if (fullscreen)
 			gtk_window_fullscreen (win);
 		gtk_widget_show (GTK_WIDGET (win));
+		gtk_window_deiconify (win);
 		gtk_window_present (win);
 	}
 
@@ -371,6 +474,7 @@ tray_menu_restore_cb (GtkWidget *item, gpointer userdata)
 	tray_toggle_visibility (FALSE);
 }
 
+#ifndef USE_APPINDICATOR
 static void
 tray_menu_notify_cb (GObject *tray, GParamSpec *pspec, gpointer user_data)
 {
@@ -398,6 +502,7 @@ tray_menu_try_restore (void)
 	tray_init();
 	return TRUE;
 }
+#endif
 
 static void
 tray_menu_quit_cb (GtkWidget *item, gpointer userdata)
@@ -524,6 +629,120 @@ tray_menu_settings (GtkWidget * wid, gpointer none)
 	setup_open ();
 }
 
+#ifdef USE_APPINDICATOR
+/* Action callbacks for GMenu */
+static void
+action_toggle_window (GSimpleAction *action, GVariant *parameter, gpointer user_data)
+{
+	tray_menu_restore_cb (NULL, NULL);
+}
+
+static void
+action_away (GSimpleAction *action, GVariant *parameter, gpointer user_data)
+{
+	tray_foreach_server (NULL, "away");
+}
+
+static void
+action_back (GSimpleAction *action, GVariant *parameter, gpointer user_data)
+{
+	tray_foreach_server (NULL, "back");
+}
+
+static void
+action_preferences (GSimpleAction *action, GVariant *parameter, gpointer user_data)
+{
+	extern void setup_open (void);
+	setup_open ();
+}
+
+static void
+action_quit (GSimpleAction *action, GVariant *parameter, gpointer user_data)
+{
+	tray_menu_quit_cb (NULL, NULL);
+}
+
+static GMenu *
+tray_create_menu (void)
+{
+	GMenu *menu;
+	GMenu *section;
+
+	/* ph may have an invalid context now */
+	hexchat_set_context (ph, hexchat_find_context (ph, NULL, NULL));
+
+	menu = g_menu_new ();
+
+	/* Window toggle */
+	section = g_menu_new ();
+	if (tray_get_window_status () == WS_HIDDEN)
+		g_menu_append (section, _("Restore Window"), "tray.toggle-window");
+	else
+		g_menu_append (section, _("Hide Window"), "tray.toggle-window");
+	g_menu_append_section (menu, NULL, G_MENU_MODEL (section));
+	g_object_unref (section);
+
+	/* Status section */
+	section = g_menu_new ();
+	g_menu_append (section, _("Away"), "tray.away");
+	g_menu_append (section, _("Back"), "tray.back");
+	g_menu_append_section (menu, NULL, G_MENU_MODEL (section));
+	g_object_unref (section);
+
+	/* Preferences and Quit */
+	section = g_menu_new ();
+	g_menu_append (section, _("Preferences"), "tray.preferences");
+	g_menu_append (section, _("Quit"), "tray.quit");
+	g_menu_append_section (menu, NULL, G_MENU_MODEL (section));
+	g_object_unref (section);
+
+	return menu;
+}
+
+static void
+tray_update_menu (void)
+{
+	if (app_menu)
+		g_object_unref (app_menu);
+
+	app_menu = tray_create_menu ();
+	app_indicator_set_menu (appindicator, app_menu);
+}
+
+static void
+tray_init (void)
+{
+	static const GActionEntry actions[] = {
+		{ "toggle-window", action_toggle_window, NULL, NULL, NULL },
+		{ "away", action_away, NULL, NULL, NULL },
+		{ "back", action_back, NULL, NULL, NULL },
+		{ "preferences", action_preferences, NULL, NULL, NULL },
+		{ "quit", action_quit, NULL, NULL, NULL },
+	};
+
+	flash_tag = 0;
+	tray_status = TS_NONE;
+	custom_icon1 = NULL;
+	custom_icon2 = NULL;
+
+	appindicator = app_indicator_new ("hexchat", ICON_NORMAL_NAME,
+									  APP_INDICATOR_CATEGORY_COMMUNICATIONS);
+	if (!appindicator)
+		return;
+
+	app_indicator_set_status (appindicator, APP_INDICATOR_STATUS_ACTIVE);
+
+	/* Set up action group */
+	action_group = g_simple_action_group_new ();
+	g_action_map_add_action_entries (G_ACTION_MAP (action_group), actions, G_N_ELEMENTS (actions), NULL);
+	app_indicator_set_actions (appindicator, action_group);
+
+	app_menu = tray_create_menu ();
+	app_indicator_set_menu (appindicator, app_menu);
+}
+
+#else /* !USE_APPINDICATOR */
+
 static void
 tray_menu_cb (GtkWidget *widget, guint button, guint time, gpointer userdata)
 {
@@ -573,9 +792,9 @@ tray_menu_cb (GtkWidget *widget, guint button, guint time, gpointer userdata)
 	menu_add_plugin_items (menu, "\x5$TRAY", NULL);
 
 	tray_make_item (menu, NULL, tray_menu_quit_cb, NULL);
-	mg_create_icon_item (_("_Preferences"), GTK_STOCK_PREFERENCES, menu, tray_menu_settings, NULL);
+	mg_create_icon_item (_("_Preferences"), "preferences-system", menu, tray_menu_settings, NULL);
 	tray_make_item (menu, NULL, tray_menu_quit_cb, NULL);
-	mg_create_icon_item (_("_Quit"), GTK_STOCK_QUIT, menu, tray_menu_quit_cb, NULL);
+	mg_create_icon_item (_("_Quit"), "application-exit", menu, tray_menu_quit_cb, NULL);
 
 	g_object_ref (menu);
 	g_object_ref_sink (menu);
@@ -591,8 +810,7 @@ tray_menu_cb (GtkWidget *widget, guint button, guint time, gpointer userdata)
 	tray_menu_timer = g_timeout_add (500, (GSourceFunc)tray_check_hide, menu);
 #endif
 
-	gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL,
-						 userdata, button, time);
+	gtk_menu_popup_at_pointer (GTK_MENU (menu), NULL);
 }
 
 static void
@@ -616,6 +834,7 @@ tray_init (void)
 	g_signal_connect (G_OBJECT (sticon), "notify::embedded",
 							G_CALLBACK (tray_menu_notify_cb), NULL);
 }
+#endif /* USE_APPINDICATOR */
 
 static int
 tray_hilight_cb (char *word[], void *userdata)
@@ -625,7 +844,11 @@ tray_hilight_cb (char *word[], void *userdata)
 
 	if (prefs.hex_input_tray_hilight)
 	{
+#ifdef USE_APPINDICATOR
+		tray_set_flash (ICON_HILIGHT_NAME);
+#else
 		tray_set_flash (ICON_HILIGHT);
+#endif
 
 		/* FIXME: hides any previous private messages */
 		tray_hilight_count++;
@@ -649,7 +872,11 @@ tray_message_cb (char *word[], void *userdata)
 		
 	if (prefs.hex_input_tray_chans)
 	{
+#ifdef USE_APPINDICATOR
+		tray_set_flash (ICON_MSG_NAME);
+#else
 		tray_set_flash (ICON_MSG);
+#endif
 
 		tray_pub_count++;
 		if (tray_pub_count == 1)
@@ -676,7 +903,11 @@ tray_priv (char *from, char *text)
 
 	if (prefs.hex_input_tray_priv)
 	{
+#ifdef USE_APPINDICATOR
+		tray_set_flash (ICON_MSG_NAME);
+#else
 		tray_set_flash (ICON_MSG);
+#endif
 
 		tray_priv_count++;
 		if (tray_priv_count == 1)
@@ -719,7 +950,11 @@ tray_dcc_cb (char *word[], void *userdata)
 
 	if (prefs.hex_input_tray_priv && (!prefs.hex_away_omit_alerts || tray_find_away_status () != 1))
 	{
+#ifdef USE_APPINDICATOR
+		tray_set_flash (ICON_FILE_NAME);
+#else
 		tray_set_flash (ICON_FILE);
+#endif
 
 		tray_file_count++;
 		if (tray_file_count == 1)
@@ -738,6 +973,9 @@ tray_focus_cb (char *word[], void *userdata)
 {
 	tray_stop_flash ();
 	tray_reset_counts ();
+#ifdef USE_APPINDICATOR
+	tray_update_menu ();
+#endif
 	return HEXCHAT_EAT_NONE;
 }
 
@@ -746,16 +984,46 @@ tray_cleanup (void)
 {
 	tray_stop_flash ();
 
+#ifdef USE_APPINDICATOR
+	if (appindicator)
+	{
+		g_object_unref ((GObject *)appindicator);
+		appindicator = NULL;
+	}
+	if (app_menu)
+	{
+		g_object_unref (app_menu);
+		app_menu = NULL;
+	}
+	if (action_group)
+	{
+		g_object_unref (action_group);
+		action_group = NULL;
+	}
+#else
 	if (sticon)
 	{
 		g_object_unref ((GObject *)sticon);
 		sticon = NULL;
 	}
+#endif
 }
 
 void
 tray_apply_setup (void)
 {
+#ifdef USE_APPINDICATOR
+	if (appindicator)
+	{
+		if (!prefs.hex_gui_tray)
+			tray_cleanup ();
+	}
+	else
+	{
+		if (prefs.hex_gui_tray)
+			tray_init ();
+	}
+#else
 	if (sticon)
 	{
 		if (!prefs.hex_gui_tray)
@@ -767,6 +1035,7 @@ tray_apply_setup (void)
 		if (prefs.hex_gui_tray && gtkutil_tray_icon_supported (window))
 			tray_init ();
 	}
+#endif
 }
 
 int
@@ -798,9 +1067,14 @@ tray_plugin_init (hexchat_plugin *plugin_handle, char **plugin_name,
 
 	hexchat_hook_print (ph, "Focus Window", -1, tray_focus_cb, NULL);
 
+#ifdef USE_APPINDICATOR
+	if (prefs.hex_gui_tray)
+		tray_init ();
+#else
 	GtkWindow *window = GTK_WINDOW(hexchat_get_info (ph, "gtkwin_ptr"));
 	if (prefs.hex_gui_tray && gtkutil_tray_icon_supported (window))
 		tray_init ();
+#endif
 
 	return 1;       /* return 1 for success */
 }
@@ -808,7 +1082,7 @@ tray_plugin_init (hexchat_plugin *plugin_handle, char **plugin_name,
 int
 tray_plugin_deinit (hexchat_plugin *plugin_handle)
 {
-#ifdef WIN32
+#if defined(WIN32) || defined(USE_APPINDICATOR)
 	tray_cleanup ();
 #endif
 	return 1;
