@@ -95,11 +95,10 @@ struct _SexySpellEntryPriv
 };
 
 static void sexy_spell_entry_class_init(SexySpellEntryClass *klass);
-static void sexy_spell_entry_editable_init (GtkEditableClass *iface);
 static void sexy_spell_entry_init(SexySpellEntry *entry);
 static void sexy_spell_entry_finalize(GObject *obj);
 static void sexy_spell_entry_destroy(GObject *obj);
-static gint sexy_spell_entry_expose(GtkWidget *widget, GdkEventExpose *event);
+static gboolean sexy_spell_entry_draw(GtkWidget *widget, cairo_t *cr);
 static gint sexy_spell_entry_button_press(GtkWidget *widget, GdkEventButton *event);
 
 /* GtkEditable handlers */
@@ -132,7 +131,7 @@ static GtkEntryClass *parent_class = NULL;
 static int codetable_ref = 0;
 #endif
 
-G_DEFINE_TYPE_EXTENDED(SexySpellEntry, sexy_spell_entry, GTK_TYPE_ENTRY, 0, G_IMPLEMENT_INTERFACE(GTK_TYPE_EDITABLE, sexy_spell_entry_editable_init));
+G_DEFINE_TYPE(SexySpellEntry, sexy_spell_entry, GTK_TYPE_ENTRY);
 
 enum
 {
@@ -243,7 +242,7 @@ sexy_spell_entry_class_init(SexySpellEntryClass *klass)
 
 	object_class->dispose = sexy_spell_entry_destroy;
 
-	widget_class->expose_event = sexy_spell_entry_expose;
+	widget_class->draw = sexy_spell_entry_draw;
 	widget_class->button_press_event = sexy_spell_entry_button_press;
 
 	/**
@@ -274,41 +273,30 @@ sexy_spell_entry_class_init(SexySpellEntryClass *klass)
 	}
 }
 
-static void
-sexy_spell_entry_editable_init (GtkEditableClass *iface)
-{
-}
-
+/* In GTK-3, we can't access GtkEntry internal fields. Use public API instead. */
 static gint
 gtk_entry_find_position (GtkEntry *entry, gint x)
 {
 	PangoLayout *layout;
 	PangoLayoutLine *line;
-	const gchar *text;
-	gint cursor_index;
 	gint index;
 	gint pos;
-	gboolean trailing;
+	gint trailing;
+	gint layout_x, layout_y;
 
-	x = x + entry->scroll_offset;
+	/* Get the layout position to offset x correctly */
+	gtk_entry_get_layout_offsets (entry, &layout_x, &layout_y);
+	x = x - layout_x;
 
-	layout = gtk_entry_get_layout(entry);
-	text = pango_layout_get_text(layout);
-	cursor_index = g_utf8_offset_to_pointer(text, entry->current_pos) - text;
+	layout = gtk_entry_get_layout (entry);
+	line = pango_layout_get_lines_readonly (layout)->data;
 
-	line = pango_layout_get_lines(layout)->data;
-	pango_layout_line_x_to_index(line, x * PANGO_SCALE, &index, &trailing);
+	if (x < 0)
+		x = 0;
 
-	if (index >= cursor_index && entry->preedit_length) {
-		if (index >= cursor_index + entry->preedit_length) {
-			index -= entry->preedit_length;
-		} else {
-			index = cursor_index;
-			trailing = FALSE;
-		}
-	}
+	pango_layout_line_x_to_index (line, x * PANGO_SCALE, &index, &trailing);
 
-	pos = g_utf8_pointer_to_offset (text, text + index);
+	pos = g_utf8_pointer_to_offset (pango_layout_get_text (layout), pango_layout_get_text (layout) + index);
 	pos += trailing;
 
 	return pos;
@@ -667,11 +655,9 @@ build_spelling_menu(SexySpellEntry *entry, const gchar *word)
 
 	/* + Add to Dictionary */
 	label = g_strdup_printf(_("Add \"%s\" to Dictionary"), word);
-	mi = gtk_image_menu_item_new_with_label(label);
+	mi = gtk_menu_item_new_with_label(label);
 	g_free(label);
 
-	gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(mi), gtk_image_new_from_stock(GTK_STOCK_ADD, GTK_ICON_SIZE_MENU));
-
 	if (g_slist_length(entry->priv->dict_list) == 1) {
 		dict = (struct EnchantDict *) entry->priv->dict_list->data;
 		g_object_set_data(G_OBJECT(mi), "enchant-dict", dict);
@@ -711,8 +697,7 @@ build_spelling_menu(SexySpellEntry *entry, const gchar *word)
 	gtk_menu_shell_append(GTK_MENU_SHELL(topmenu), mi);
 
 	/* - Ignore All */
-	mi = gtk_image_menu_item_new_with_label(_("Ignore All"));
-	gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(mi), gtk_image_new_from_stock(GTK_STOCK_REMOVE, GTK_ICON_SIZE_MENU));
+	mi = gtk_menu_item_new_with_label(_("Ignore All"));
 	g_signal_connect(G_OBJECT(mi), "activate", G_CALLBACK(ignore_all), entry);
 	gtk_widget_show_all(mi);
 	gtk_menu_shell_append(GTK_MENU_SHELL(topmenu), mi);
@@ -723,7 +708,7 @@ build_spelling_menu(SexySpellEntry *entry, const gchar *word)
 static void
 sexy_spell_entry_populate_popup(SexySpellEntry *entry, GtkMenu *menu, gpointer data)
 {
-	GtkWidget *icon, *mi;
+	GtkWidget *mi;
 	gint start, end;
 	gchar *word;
 
@@ -745,9 +730,7 @@ sexy_spell_entry_populate_popup(SexySpellEntry *entry, GtkMenu *menu, gpointer d
 	gtk_menu_shell_prepend(GTK_MENU_SHELL(menu), mi);
 
 	/* Above the separator, show the suggestions menu */
-	icon = gtk_image_new_from_stock(GTK_STOCK_SPELL_CHECK, GTK_ICON_SIZE_MENU);
-	mi = gtk_image_menu_item_new_with_label(_("Spelling Suggestions"));
-	gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(mi), icon);
+	mi = gtk_menu_item_new_with_label(_("Spelling Suggestions"));
 
 	word = gtk_editable_get_chars(GTK_EDITABLE(entry), start, end);
 	g_assert(word != NULL);
@@ -1115,25 +1098,20 @@ sexy_spell_entry_recheck_all(SexySpellEntry *entry)
 	}
 }
 
-static gint
-sexy_spell_entry_expose(GtkWidget *widget, GdkEventExpose *event)
+static gboolean
+sexy_spell_entry_draw(GtkWidget *widget, cairo_t *cr)
 {
 	SexySpellEntry *entry = SEXY_SPELL_ENTRY(widget);
 	GtkEntry *gtk_entry = GTK_ENTRY(widget);
 	PangoLayout *layout;
 
-	
 	layout = gtk_entry_get_layout(gtk_entry);
-	if (gtk_entry->preedit_length == 0)
-	{
-		pango_layout_set_attributes(layout, entry->priv->attr_list);
-	}
-	else
-	{
-		pango_layout_set_attributes(layout, empty_attrs_list);
-	}
+	
+	/* In GTK-3, we always apply spell check attributes.
+	 * The entry handles preedit text rendering internally. */
+	pango_layout_set_attributes(layout, entry->priv->attr_list);
 
-	return GTK_WIDGET_CLASS(parent_class)->expose_event (widget, event);
+	return GTK_WIDGET_CLASS(parent_class)->draw(widget, cr);
 }
 
 static gint
@@ -1255,7 +1233,7 @@ void
 sexy_spell_entry_activate_default_languages(SexySpellEntry *entry)
 {
 	GSList *enchant_langs;
-	char *lang, *langs;
+	char *lang, **i, **langs;
 
 	if (!have_enchant)
 		return;
@@ -1265,21 +1243,21 @@ sexy_spell_entry_activate_default_languages(SexySpellEntry *entry)
 
 	enchant_langs = sexy_spell_entry_get_languages(entry);
 
-	langs = g_strdup (prefs.hex_text_spell_langs);
+	langs = g_strsplit_set (prefs.hex_text_spell_langs, ", \t", 0);
 
-	lang = strtok (langs, ",");
-	while (lang != NULL)
+	for (i = langs; *i; i++)
 	{
+		lang = *i;
+
 		if (enchant_has_lang (lang, enchant_langs))
 		{
 			sexy_spell_entry_activate_language_internal (entry, lang, NULL);
 		}
-		lang = strtok (NULL, ",");
 	}
 
 	g_slist_foreach(enchant_langs, (GFunc) g_free, NULL);
 	g_slist_free(enchant_langs);
-	g_free (langs);
+	g_strfreev (langs);
 
 	/* If we don't have any languages activated, use "en" */
 	if (entry->priv->dict_list == NULL)
